@@ -31,13 +31,13 @@ import socket
 import sys
 import subprocess
 import argparse
+import io
 
-system_version = "2.4.4"  # This MUST MATCH the version specified in setup.py
+system_version = "2.4.5"  # This MUST MATCH the version specified in setup.py
 api_version = "0.0.3"
 
 IS_PY3 = sys.version_info.major == 3
 
-
 if IS_PY3:
     # Python 3
     import configparser
@@ -802,6 +802,7 @@ def process_file_request(download_url, file_new_name=None):
 def get_post_image(picture_id=None, do_log=True):
     if do_log:
         log("Should take picture!")
+
     was_none = ""
     json_return = None
 
@@ -815,7 +816,7 @@ def get_post_image(picture_id=None, do_log=True):
         try:
             if octoprint_settings["webcam"]["webcamEnabled"]:
                 the_url = octoprint_settings["webcam"]["snapshotUrl"]
-                new_name = str(picture_id) + ".png"
+                new_name = os.path.join(dir_path, "files/" + str(picture_id) + ".png")
 
                 if do_log:
                     log("Taking picture...")
@@ -996,3 +997,17 @@ def set_display(text, short_branding=False):
 
         octoprint_api_req("printer/command", {"command": "M117 " + prefix + " " + str(text)})
 
+
+def webrequest_pid(make_new=True):
+    webrequest_pid_file = os.path.join(dir_path, "webrequest_pid.txt")
+    if os.path.exists(webrequest_pid_file):
+        with io.open(webrequest_pid_file, "rt", encoding="utf-8") as f:
+            s = f.read()
+            try:
+                os.kill(int(s), signal.SIGSTOP)
+            except:
+                pass
+
+    if make_new:
+        with open(webrequest_pid_file, "wt", encoding="utf-8") as file:
+            file.write(str(os.getpid()))
