@@ -18,10 +18,12 @@ from __future__ import absolute_import, division, unicode_literals
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+from .base import *
 from crontab import CronTab
 import subprocess
 import sys
-
+import os
+import shutil
 
 def run_uninstall():
     # Remove cron jobs
@@ -34,7 +36,11 @@ def run_uninstall():
 
     cron.write()
 
-    # TODO; kill all running SimplyPrint scripts
+    # Stop running SimplyPrint scripts
+    webrequest_pid(False)
+
+    # Delete local SimplyPrint folder containing logs and stuff
+    shutil.rmtree(dir_path, ignore_errors=True)
 
     # Delete ourselves using pip
     subprocess.Popen([sys.executable, "-m", "pip", "uninstall", "-y", "SimplyPrintRPiSoftware"])
