@@ -25,7 +25,6 @@ import subprocess
 import sys
 from datetime import datetime
 
-
 start_time = time.time()
 times_a_minute = config.getint("info", "requests_per_minute")
 
@@ -418,19 +417,19 @@ def do_the_request(num):
 
                     if has_demand("system_reboot"):
                         set_display("Rebooting...", True)
-                        os.system("sudo shutdown -r now")
+                        os.system("shutdown -r now")
                         return True
 
                     if has_demand("system_shutdown"):
                         set_display("Shutting down", True)
-                        os.system("sudo shutdown -h now")
+                        os.system("shutdown -h now")
                         return True
 
                     if has_demand("start_octoprint"):
-                        os.system("sudo service octoprint start")
+                        os.system("service octoprint start")
 
                     if has_demand("shutdown_octoprint"):
-                        os.system("sudo service octoprint stop")
+                        os.system("service octoprint stop")
 
                     if has_demand("restart_octoprint"):
                         os.system("sudo service octoprint restart")
@@ -541,11 +540,18 @@ def do_the_request(num):
                                 })
 
                                 # Install through pip, and restart OctoPrint
-                                os.system(
-                                    "yes | " + sys.executable + " uninstall \"" + action["pip_name"] + "\"")
-
-                                os.system(
-                                    "yes | " + sys.executable + " install \"" + action["install_url"] + "\"")
+                                command_uninstall = [sys.executable, "-m", "pip", "uninstall", "-y", + action["pip_name"]]
+                                command_install = [sys.executable, "-m", "pip", "install", action["install_url"]]
+                                process = subprocess.Popen(command_uninstall, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+                                stdout, stderr = process.communicate()
+                                log("Uninstall command, stdout" + str(stdout.decode("utf-8", errors="replace")))
+                                log("Uninstall command, stderr" + str(stderr.decode("utf-8", errors="replace")))
+                                
+                                command_install = [sys.executable, "-m", "pip", "install", action["install_url"]]
+                                process2 = subprocess.Popen(command_install, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+                                stdout, stderr = process2.communicate()
+                                log("Uninstall command, stdout" + str(stdout.decode("utf-8", errors="replace")))
+                                log("Uninstall command, stderr" + str(stderr.decode("utf-8", errors="replace")))
 
                                 do_restart_octoprint = True
                             elif action["type"] == "uninstall":
@@ -577,7 +583,7 @@ def do_the_request(num):
                                             f.write(line + "\n")
 
                                 os.system(
-                                    "yes | " + sys.executable + " uninstall \"" + action["pip_name"].replace(
+                                    "yes | " + sys.executable + " -m pip uninstall \"" + action["pip_name"].replace(
                                         " ", "-") + "\"")
                                 do_restart_octoprint = True
                             elif action["type"] == "set_settings":
@@ -785,6 +791,7 @@ def do_the_request(num):
 
 
 def run_requests():
+    webrequest_pid()
     print("Starting loop...")
 
     i = 0  # Skip the last one - cron handles the last by doing it again, so cut it off
